import 'dart:convert';
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:pusher_websocket_flutter/pusher.dart';
import 'package:flutter_screenutil/screen_util.dart';

import '../widgets/messages_item.dart';

class ChatScreen extends StatefulWidget {
  final String senderName;
  final String about;
  final String senderImage;
  final FeedPost post;
  final UserModel currentUser;
  final loc;

  const ChatScreen({
    @required this.senderName,
    @required this.about,
    @required this.senderImage,
    @required this.post,
    @required this.currentUser,
    @required this.loc,
  });

  @override
  _ChatScreenState createState() => _ChatScreenState();
}

class _ChatScreenState extends State<ChatScreen> {
  double defaultScreenWidth = 375.0;
  double defaultScreenHeight = 812.0;
  FocusNode focusNode;
  bool isChatBuild;

  List<PostCommentModel> commentsList;

  Future<UserModel> getUserById(id) async {
    UserModel user = await feedRepository.fetchUserData(id);
    return user;
  }

  ScrollController _scrollController;
  HttpService httpService;
  FeedRepository feedRepository;
  Channel _channelComment;
  TextEditingController _textEditingController;

  int commentsLength;

  Future<List<PostCommentModel>> getCommentsList() async {
    commentsList =
        await feedRepository.fetchPostComments(this.widget.post.postData.id);
    return commentsList;
  }

  loadData() async {
    await getCommentsList().then(
      (data) {
        setState(
          () {
            commentsList = data;
          },
        );
      },
    );
  }

  @override
  void initState() {
    commentsLength = 0;
    _textEditingController = TextEditingController();
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
    focusNode = FocusNode();
    // focusNode.requestFocus();
    commentsList = [];
    loadData();
    _initPusher();
    _scrollController = ScrollController();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    _textEditingController.dispose();
    focusNode.dispose();
    super.dispose();
  }

  Future<void> _initPusher() async {
    _channelComment = await Pusher.subscribe('comment');

    _channelComment.bind('create_comment', (onEvent) {
      List<dynamic> newComment = json.decode(onEvent.data);
      List<PostCommentModel> comments =
          newComment.map((i) => PostCommentModel.fromJson(i)).toList();
      if (mounted) {
        this.setState(() {
          if (comments[0].post.id == this.widget.post.postData.id) {
            commentsList.add(comments[0]);
            commentsLength = commentsList.length;
          }
        });
      }
    });

    _channelComment.bind('remove_comment', (onEvent) {
      int id = int.parse(onEvent.data);
      List<PostCommentModel> comments =
          commentsList.where((comment) => comment.id != id).toList();
      if (mounted) {
        this.setState(() {
          commentsList = comments;
          commentsLength = comments.length == 0 ? -1 : comments.length;
        });
      }
    });
  }

  void _sendMessage() {
    if (_textEditingController.text.isEmpty) return;
    HttpService("jhgvf").uploadComment(
        userId: this.widget.currentUser.id,
        postId: this.widget.post.postData.id,
        comment: _textEditingController.text);
    focusNode.unfocus();

    setState(() {
      _textEditingController.text = "";
    });
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(defaultScreenWidth, defaultScreenHeight),
        allowFontScaling: true,
        builder: () =>
            // LayoutBuilder(
            //   builder: (_, BoxConstraints constraints) {
            //     return MaterialApp(
            //       home:
            Scaffold(
          appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              leading: GestureDetector(
                  onTap: () {
                    FeedPost thisPost = FeedPost(
                        loc: this.widget.loc,
                        postData: this.widget.post.postData,
                        currentUser: this.widget.post.currentUser,
                        likeId: this.widget.post.likeId,
                        dislikeId: this.widget.post.dislikeId,
                        saveId: this.widget.post.saveId,
                        images: this.widget.post.images,
                        commentsLength: commentsLength);
                    Navigator.pop(context, thisPost);
                  },
                  child: Padding(
                    padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                    child: Icon(Icons.arrow_back, color: Colors.white),
                  )),
            ),
          ),
          backgroundColor: Colors.white,
          body: Directionality(
            textDirection: TextDirection.ltr,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Expanded(
                  child: ListView(
                    children: [
                      FeedPost(
                        postData: this.widget.post.postData,
                        currentUser: this.widget.post.currentUser,
                        likeId: this.widget.post.likeId,
                        dislikeId: this.widget.post.dislikeId,
                        saveId: this.widget.post.saveId,
                        images: this.widget.post.images,
                        commentsLength: commentsLength,
                        loc: this.widget.loc,
                      ),
                      Divider(
                        color: Color(0xffE8ECEF),
                      ),
                      Padding(
                        padding: EdgeInsets.only(
                          left: ScreenUtil().setWidth(16),
                          // right: ScreenUtil().setWidth(275),
                          top: ScreenUtil().setWidth(20),
                          bottom: ScreenUtil().setWidth(30),
                        ),
                        child: Container(
                          child: Text(
                            this.widget.loc.translate('Comments'),
                            style: TextStyle(
                              fontWeight: FontWeight.w500,
                              color: Colors.black,
                              fontSize: ScreenUtil().setSp(16),
                              fontFamily: 'Rubik',
                            ),
                          ),
                        ),
                      ),
                      Container(
                        child: ListView.builder(
                          shrinkWrap: true,
                          reverse: true,
                          physics: ClampingScrollPhysics(),
                          controller: _scrollController,
                          itemCount: commentsList.length,
                          itemBuilder: (ctx, index) => commentsList[index]
                                      .post
                                      .id ==
                                  this.widget.post.postData.id
                              ? MessagesItem(
                                  postCommentModel: commentsList[index],
                                  isUserMassage: commentsList[index].user.id ==
                                          this.widget.currentUser.id
                                      ? true
                                      : false,
                                  commentId: commentsList[index].id,
                                  loc:this.widget.loc,
                                  // about: this.widget.about,
                                  // currentUser: this.widget.currentUser,
                                  // post: this.widget.post,
                                  // senderImage: this.widget.senderImage,
                                  // senderName: this.widget.senderName,
                                )
                              : null,
                        ),
                      ),
                    ],
                  ),
                ),
                // Visibility(
                //   visible: _isTyping,
                //   child: Padding(
                //     padding: const EdgeInsets.all(8.0),
                //     child: Row(
                //       children: <Widget>[
                //         Text(
                //           '$_userNameTyping is typing',
                //           style: Theme.of(context).textTheme.headline6.copyWith(
                //                 color: Colors.black54,
                //                 fontWeight: FontWeight.w400,
                //                 fontSize: 14,
                //               ),
                //         ),
                //       ],
                //     ),
                //   ),
                // ),
                Container(
                  decoration: BoxDecoration(
                    color: Colors.white,
                    boxShadow: <BoxShadow>[
                      BoxShadow(
                        color: Colors.grey[300],
                        offset: new Offset(5.0, 5.0),
                        blurRadius: 20.0,
                      )
                    ],
                  ),
                  child: Padding(
                    padding:
                        const EdgeInsets.symmetric(horizontal: 10, vertical: 5),
                    child: Row(
                      children: <Widget>[
                        // Container(
                        // padding:
                        //     EdgeInsets.only(right: ScreenUtil().setWidth(50)),
                        // child:
                        Padding(
                          padding: EdgeInsets.only(
                            left: ScreenUtil().setWidth(16),
                            right: ScreenUtil().setWidth(8),
                          ),
                          child: this.widget.currentUser.profileImg == null || this.widget.currentUser.profileImg == ""||this.widget.currentUser.profileImg == "null"
                              ? DefaultProfileImg(
                                  firstName: this.widget.currentUser.firstName,
                                  lastName: this.widget.currentUser.lastName)
                              // ClipOval(
                              //     child: Material(
                              //       color: Color(0xffE8ECEF),
                              //       child: SizedBox(
                              //         width: ScreenUtil().setWidth(38),
                              //       height: ScreenUtil().setWidth(39),
                              //       child: Center(
                              //         child: Text(
                              //           this
                              //                   .widget
                              //                   .currentUser
                              //                   .firstName
                              //                   .substring(0, 1) +
                              //               this
                              //                   .widget
                              //                   .currentUser
                              //                   .lastName
                              //                   .substring(0, 1),
                              //           style: TextStyle(
                              //             color: Color(0xFF083356),
                              //             fontSize: ScreenUtil().setSp(15),
                              //           ),
                              //         ),
                              //       ),
                              //     ),
                              //   ),
                              // )
                              : ClipOval(
                                  child: Image.network(
                                    this.widget.currentUser.profileImg,
                                    width: ScreenUtil().setWidth(38),
                                    height: ScreenUtil().setWidth(39),
                                    fit: BoxFit.cover,
                                  ),
                                ),
                        ),
                        // ),
                        Expanded(
                          child: Theme(
                            data: Theme.of(context)
                                .copyWith(splashColor: Colors.transparent),
                            child: TextField(
                              focusNode: focusNode,
                              maxLength: 1000,
                              keyboardType: TextInputType.multiline,
                              maxLines: null,
                              maxLengthEnforcement:
                                  MaxLengthEnforcement.enforced,
                              onSubmitted: (_) {
                                _sendMessage();
                              },
                              controller: _textEditingController,
                              decoration: InputDecoration(
                                contentPadding: const EdgeInsets.symmetric(
                                    vertical: 1.0, horizontal: 10),
                                hintText: this
                                    .widget
                                    .loc
                                    .translate('Type your comment...'),
                                hintStyle: TextStyle(
                                  fontSize: ScreenUtil().setSp(14),
                                  color: Color(0xff98A9BC),
                                ),
                                alignLabelWithHint: true,
                                filled: true,
                                fillColor: Color(0xffF5F5F5),
                                counterText: "",
                                border: OutlineInputBorder(
                                  borderSide: BorderSide(
                                    color: Colors.grey,
                                  ),
                                  borderRadius: BorderRadius.circular(30),
                                ),
                              ),
                            ),
                          ),
                        ),
                        Container(
                          padding: const EdgeInsets.only(left: 10),
                          child: ClipOval(
                              child: Material(
                            color: Color(0xFF3DD598),
                            child: InkWell(
                              splashColor: Color(0xFFFCA64F),
                              child: IconButton(
                                onPressed: _sendMessage,
                                icon: Icon(FontAwesomeIcons.telegramPlane),
                                color: Colors.white,
                                iconSize: 30,
                              ),
                            ),
                          )),
                        ),
                      ],
                    ),
                  ),
                ),
                // MessageForm(
                //   postId: this.widget.post.postData.id,
                //   currentUser: this.widget.currentUser,
                // ),
              ],
            ),
          ),
        ),
        //     );
        //   },
        // ),
      ),
    );
  }
}
