import 'package:feed_plugin/models/media.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
// import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:flutter/material.dart';
import 'dart:async';
import 'package:intl/intl.dart';
import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/pages/my_feed.dart';
import 'package:feed_plugin/pages/partner_feed.dart';
import 'package:feed_plugin/pages/share_post_page.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:pusher_websocket_flutter/pusher.dart';
// import 'package:scrollable_positioned_list/scrollable_positioned_list.dart';
import 'dart:convert';
import '../environment_config.dart';
import 'package:empty_widget/empty_widget.dart';

final lastDate = new DateTime(
  DateTime.now().year - 10,
  DateTime.now().month,
);

String selectedValue = lastDate.toString();

class HomePage extends StatefulWidget {
  const HomePage(
      {Key key,
      this.token,
      this.firstName,
      this.lastName,
      this.about,
      this.profileImg,
      this.partnerName,
      this.partnerProfileImg,
      this.partnerMedia,
      // this.currentPartner,
      // this.currentUser,
      this.loc})
      : super(key: key);

  final String token;
  final String firstName;
  final String lastName;
  final String about;
  final String profileImg;
  final String partnerName;
  final String partnerProfileImg;
  // final UserModel currentPartner;
  // final UserModel currentUser;
  final partnerMedia;
  final loc;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final int increment = 1;
  bool isLoadingVertical = false;
  List<PostModel> postsList = [];
  List<PostModel> postsListFilter = [];
  UserModel currentPartner;
  UserModel currentUser;
  bool newPostFlag = false;
  Channel _channel;
  // var _scrollController = ScrollController();
  ScrollController _scrollController = new ScrollController();
  double defaultScreenWidth = 375.0;
  double defaultScreenHeight = 812.0;
  final int likeId = 1;
  final int dislikeId = 3;
  final int saveId = 2;
  bool flagFilter;
  int count;
  HttpService httpService;
  FeedRepository feedRepository;
  List<FeedPost> list;

  @override
  void initState() {
    // _loadMoreVertical();
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    flagFilter = false;
    count = 0;
    initPusher();
    getCurrentUserAndPartner();
    getPosts();
    super.initState();
  }

  dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  Future<void> initPusher() async {
    try {
      await Pusher.init(
          EnvironmentConfig.PUSHER_ENV, PusherOptions(cluster: 'ap2'));
    } catch (e) {
      print(e);
    }

    Pusher.connect(onConnectionStateChange: (val) {}, onError: (err) {});

    _channel = await Pusher.subscribe('post');
    _channel.bind(
      'create_post',
      (onEvent) {
        List<dynamic> newPost = json.decode(onEvent.data);
        List<PostModel> postsList =
            newPost.map((i) => PostModel.fromJson(i)).toList();
        List<PostModel> posts1 = postsListFilter.reversed.toList();
        // List<FeedPost> feed1 = list.reversed.toList();
        if (mounted) {
          this.setState(() {
            posts1.add(postsList[0]);
            // feed1.add(FeedPost(
            //     postData: postsList[0],
            //     currentUser: currentUser,
            //     likeId: likeId,
            //     dislikeId: dislikeId,
            //     saveId: saveId,
            //     images: postsList[0].attachedUrl.split(","),
            //     commentsLength: 0));
            postsListFilter = posts1.reversed.toList();
            // list = feed1.reversed.toList();
            newPostFlag = true;
          });
        }
      },
    );

    _channel.bind(
      'remove_post',
      (onEvent) {
        int postId = int.parse(onEvent.data);
        List<PostModel> posts = [];
        postsListFilter.forEach(
          (post) {
            if (post.id != postId) {
              posts.add(post);
            }
          },
        );
        if (mounted) {
          this.setState(
            () {
              postsListFilter = posts;
            },
          );
        }
      },
    );
  }

  Future<List<PostModel>> getPosts() async {
    List<PostModel> posts = [];
    // await getPostsReports();
    posts = await loadPosts();
    return posts;
  }

  Future<UserModel> getCurrentUserAndPartner() async {
    await feedRepository
        .authenticateUser(widget.firstName, widget.lastName, widget.about,
            widget.profileImg, widget.token, null)
        .then((user) => {
              setState(
                () {
                  currentUser = user;
                },
              )
            });
    return currentUser;
  }

  // Future getPostsReports() async {

  //   List<ReportSubTypeModel> reportsSubTypeList = await feedRepository.fetchAllSubType();

  //   for (var i = 0; i < reportsSubTypeList.length; i++) {
  //     if (likeId == null || dislikeId == null || saveId == null) {
  //       if (reportsSubTypeList[i].type == "Like") {
  //         likeId = reportsSubTypeList[i].id;
  //       } else if (reportsSubTypeList[i].type == "Dislike") {
  //         dislikeId = reportsSubTypeList[i].id;
  //       } else if (reportsSubTypeList[i].type == "Save") {
  //         saveId = reportsSubTypeList[i].id;
  //       }
  //     } else {
  //       break;
  //     }
  //   }
  // }

  void startTimer(int num) {
    count = num;
    Timer.periodic(
      Duration(seconds: 1),
      (_timer) {
        if (count > 0) {
          count--;
        } else {
          _timer.cancel();
          setState(
            () {
              newPostFlag = false;
            },
          );
        }
      },
    );
  }

  bool filter({@required DateTime createdAt, @required String selectedDate}) {
    DateTime fromDate = createdAt;
    DateTime toDate = new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    if (fromDate.isAfter(toDate) || toDate == fromDate) {
      return true;
    }
    return false;
  }

  bool filterByDay(
      {@required DateTime createdAt, @required String selectedDate}) {
    DateTime theDate =
        new DateFormat("yyyy-MM-dd hh:mm:ss").parse(selectedDate);
    setState(
      () {
        flagFilter = true;
      },
    );
    if (theDate.day == createdAt.day &&
        theDate.month == createdAt.month &&
        theDate.year == createdAt.year) {
      return true;
    }
    return false;
  }

  void getPostsByFilter() {
    List<PostModel> postsListTemp = [];

    for (var i = 0; i < postsList.length; i++) {
      if (filterByDay(
          createdAt: postsList[i].createdAt, selectedDate: selectedValue))
      // filter(createdAt: postsList[i].createdAt, selectedDate: selectedValue))
      {
        postsListTemp.add(postsList[i]);
      }
    }
    setState(
      () {
        postsListFilter = postsListTemp;
      },
    );
  }

  List<PostModel> posts = [];

  buildList(List<PostModel> myPostsList) {
    list = [];
    List<String> images = [];

    myPostsList.forEach((post1) {
      images = post1.attachedUrl.split(",");
      setState(() {
        list.add(
          FeedPost(
            key: GlobalKey(),
            postData: post1,
            currentUser: this.currentUser,
            images: images,
            likeId: likeId,
            dislikeId: dislikeId,
            saveId: saveId,
            commentsLength: 0,
            loc: this.widget.loc,
          ),
        );
      });
    });
  }

  Future<List<PostModel>> loadPosts() async {
    // list = [];
    await feedRepository.loadPosts().then((value) async => {
          // await buildList(value.reversed.toList()),
          setState(() {
            posts = value;
            postsListFilter = posts.reversed.toList();
            postsList = posts.reversed.toList();
          })
        });
    // this.setState(
    //   () {
    //     postsListFilter = posts;
    //     // postsListFilter.addAll(posts.getRange(
    //     //   postsListFilter.length, postsListFilter.length+increment));
    //     postsList = posts;
    //   },
    // );
    return postsListFilter;
  }

  Future refreshData() async {
    await getPosts();
    return;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(70.0),
        child: AppBar(
          automaticallyImplyLeading: false,
          backgroundColor: Color(0xFF083356),
          actions: <Widget>[
            Container(
              child: this.currentUser != null
                  ? GestureDetector(
                      onTap: () {
                        Navigator.pop(context);
                      },
                      child: GestureDetector(
                        onTap: () {
                          Media media =  Media.fromJson(jsonDecode(widget.partnerMedia));
                          Navigator.push(
                            context,
                            MaterialPageRoute(
                              builder: (context) => PartnerFeedPage(
                                loc: this.widget.loc,
                                currentUser: this.currentUser,
                                saveId: saveId,
                                likeId: likeId,
                                dislikeId: dislikeId,
                                profileImg: widget.partnerProfileImg,
                                firstName: widget.partnerName,
                                media:media,
                              ),
                            ),
                          );
                        },
                        child: Padding(
                          padding:
                              EdgeInsets.only(right: ScreenUtil().setWidth(10)),
                          child: Container(
                            alignment: Alignment.bottomRight,
                            child: this.widget.partnerProfileImg == null || this.widget.partnerProfileImg == ""||this.widget.partnerProfileImg == "null"
                                ? DefaultProfileImg(
                                    firstName: this.widget.partnerName,
                                  )
                                // ClipOval(
                                //     child: Material(
                                //       color: Color(0xffE8ECEF),
                                //       child: SizedBox(
                                //         width: ScreenUtil().setWidth(38),
                                //         height: ScreenUtil().setWidth(39),
                                //         child: Center(
                                //           child: Text(
                                //             this
                                //                 .widget
                                //                 .partnerName
                                //                 .substring(0, 1),
                                //             style: TextStyle(
                                //               color: Color(0xFF083356),
                                //               fontSize: ScreenUtil().setSp(15),
                                //             ),
                                //           ),
                                //         ),
                                //       ),
                                //     ),
                                //   )
                                : ClipOval(
                                    child: Image.network(
                                      this.widget.partnerProfileImg,
                                      width: ScreenUtil().setWidth(40),
                                      height: ScreenUtil().setWidth(40),
                                      fit: BoxFit.cover,
                                    ),
                                  ),
                          ),
                        ),
                      ),
                    )
                  : Padding(
                      padding: EdgeInsets.only(
                        right: ScreenUtil().setWidth(10),
                      ),
                      child: Container(),
                    ),
            ),
          ],
          // leading:
          //  IconButton(
          //   icon: Icon(Icons.arrow_back),
          //   onPressed: () {
          //     Navigator.pop(context);
          //   },
          // ),
          title: Row(
            children: [
              this.currentUser != null
                  ? GestureDetector(
                      // onTap: () {
                      //   Navigator.pop(context);
                      // },
                      // child:
                      //  GestureDetector(
                      onTap: () async {
                        // List<FeedPost> myFeeds = [];
                        // list.forEach((f)=>{
                        //   if(f.postData.user.id == currentUser.id){
                        //     myFeeds.add(f)
                        //   }
                        // });

                        List<PostModel> myPosts = postsListFilter
                            .where((p) => p.user.id == currentUser.id)
                            .toList();
                        var result = await Navigator.push(
                          context,
                          MaterialPageRoute(
                            builder: (context) => MyFeedPage(
                              // currentPartner: this.widget.currentPartner,
                              currentUser: this.currentUser,
                              saveId: saveId,
                              likeId: likeId,
                              dislikeId: dislikeId,
                              postsList: myPosts,
                              loc: this.widget.loc,
                            ),
                          ),
                        );
                        await loadPosts();
                        // setState(() {
                        //   currentPartner = result.currentPartner;
                        //   currentUser = result.currentUser;
                        // postsListFilter = List.from(postsListFilter)
                        //   ..add(Fed)
                        // });
                      },
                      child: Padding(
                        padding:
                            EdgeInsets.only(top: ScreenUtil().setWidth(12)),
                        child: Container(
                          alignment: Alignment.centerLeft,
                          child: this.currentUser.profileImg != null  && this.currentUser.profileImg != "" && this.currentUser.profileImg != "null"
                              ? ClipOval(
                                  child: Image.network(
                                    this.currentUser.profileImg,
                                    width: ScreenUtil().setWidth(38),
                                    height: ScreenUtil().setWidth(39),
                                    fit: BoxFit.cover,
                                  ),
                                )
                              : DefaultProfileImg(
                                  firstName: this.widget.firstName,
                                  lastName: this.widget.lastName),
                          // : ClipOval(
                          //     child: Material(
                          //       color: Color(0xffE8ECEF),
                          //       child: SizedBox(
                          //         width: ScreenUtil().setWidth(38),
                          //         height: ScreenUtil().setWidth(39),
                          //         child: Center(
                          //           child: Text(
                          //             this
                          //                     .widget
                          //                     .firstName
                          //                     .substring(0, 1) +
                          //                 this
                          //                     .widget
                          //                     .lastName
                          //                     .substring(0, 1),
                          //             style: TextStyle(
                          //               color: Color(0xFF083356),
                          //               fontSize: ScreenUtil().setSp(15),
                          //             ),
                          //           ),
                          //         ),
                          //       ),
                          //     ),
                          //   ),
                        ),
                      ),
                    )
                  : Container(),
              Padding(
                padding: EdgeInsets.only(
                  left: ScreenUtil().setWidth(50),
                  top: ScreenUtil().setWidth(10),
                ),
                child: Text(
                  this.widget.loc.translate('Feed'),
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ],
          ),
        ),
      ),
      body: postsListFilter.length < 1 && flagFilter
          ? GestureDetector(
              onTap: () {
                setState(
                  () {
                    postsListFilter = postsList;
                    flagFilter = false;
                  },
                );
              },
              child: Center(
                child: EmptyListWidget(
                  title: this.widget.loc.translate('No Data Found'),
                  subTitle:
                      this.widget.loc.translate('Click here to see all posts'),
                  packageImage: PackageImage.Image_3,
                  titleTextStyle: Theme.of(context)
                      .typography
                      .dense
                      .headline4
                      .copyWith(color: Color(0xff9da9c7)),
                  subtitleTextStyle:
                      Theme.of(context).typography.dense.bodyText1.copyWith(
                            color: Color(0xffabb8d6),
                          ),
                ),
              ),
            )
          : postsListFilter.length < 1 && !flagFilter
              ? Center(child: LoadingIndicatorDark())
              : Column(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: [
                    if (newPostFlag == true) _newPostButton(),
                    _buildDateField(),
                    Expanded(
                      child: this.currentUser != null
                          ? Stack(
                              children: [
                                RefreshIndicator(
                                    triggerMode:
                                        RefreshIndicatorTriggerMode.anywhere,
                                    onRefresh: () => getPosts(),
                                    child: ListView.builder(
                                      physics:
                                          const AlwaysScrollableScrollPhysics(),
                                      // reverse: true,
                                      // cacheExtent: 9999,
                                      controller: _scrollController,
                                      itemCount: postsListFilter.length,
                                      itemBuilder:
                                          (BuildContext context, int index) {
                                        PostModel post = postsListFilter[index];
                                        List<String> images =
                                            postsListFilter[index]
                                                .attachedUrl
                                                .split(",");
                                        // FeedPost feed = list[index];
                                        return Container(
                                          decoration: BoxDecoration(
                                            border: Border(
                                              bottom: BorderSide(
                                                width: 15,
                                                color: Color(0xffE8ECEF),
                                              ),
                                            ),
                                          ),
                                          child: FeedPost(
                                            key: Key("F" + post.id.toString()),
                                            postData: post,
                                            currentUser: this.currentUser,
                                            images: images,
                                            likeId: likeId,
                                            dislikeId: dislikeId,
                                            saveId: saveId,
                                            commentsLength: 0,
                                            loc: this.widget.loc,
                                          ),

                                          // feed,
                                        );
                                      },
                                      // separatorBuilder:
                                      //     (BuildContext context, int index) =>
                                      //         const Divider(),
                                    )),
                                //   ],
                                // )
                                //   ),
                                // ),
                                // if (newPostFlag == true) _newPostButton(),
                                Align(
                                  alignment: Alignment(0.8, 0.85),
                                  child: Container(
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      boxShadow: [
                                        BoxShadow(
                                          color: Colors.grey,
                                          blurRadius: 5.0,
                                          spreadRadius: 1.0,
                                        )
                                      ],
                                    ),
                                    child: ClipOval(
                                      child: Material(
                                        color: Color(0xFF3DD598),
                                        child: InkWell(
                                          splashColor: Color(0xFFFCA64F),
                                          child: SizedBox(
                                            width: 70,
                                            height: 70,
                                            child: Icon(Icons.add,
                                                size: 50.0,
                                                color: Colors.white),
                                          ),
                                          onTap: () {
                                            Navigator.push(
                                              context,
                                              MaterialPageRoute(
                                                  builder: (context) =>
                                                      SharePostPage(
                                                          currentUser:
                                                              this.currentUser,
                                                          loc:
                                                              this.widget.loc)),
                                            );
                                          },
                                        ),
                                      ),
                                    ),
                                  ),
                                )
                              ],
                            )
                          : Container(),
                    ),
                  ],
                ),
    );
  }

  _newPostButton() {
    startTimer(7);
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(64),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(44),
            width: ScreenUtil().setWidth(280),
            child: Container(
              decoration: ShapeDecoration(
                color: Color(0xFF3DD598),
                shape: RoundedRectangleBorder(
                  side: BorderSide(
                      color: Colors.transparent,
                      width: 1,
                      style: BorderStyle.solid),
                  borderRadius: BorderRadius.circular(60),
                ),
              ),
              //ignore: deprecated_member_use
              child: FlatButton(
                onPressed: () {
                  startTimer(0);
                  _scrollController.animateTo(
                      _scrollController.position.minScrollExtent,
                      duration: Duration(seconds: 1),
                      curve: Curves.fastOutSlowIn);
                },
                child: Center(
                  child: Row(
                    children: [
                      Expanded(
                        child: Align(
                          alignment: Alignment.centerRight,
                          child: Text(
                            this.widget.loc.translate('New Post'),
                            style: TextStyle(
                              fontSize: ScreenUtil().setSp(16),
                              color: Colors.white,
                              fontFamily: 'Rubik',
                            ),
                          ),
                        ),
                      ),
                      Expanded(
                        child: Align(
                          alignment: Alignment.centerLeft,
                          child: Row(
                            children: [
                              Text("    "),
                              Icon(
                                Icons.arrow_forward,
                                size: ScreenUtil().setWidth(35),
                                color: Colors.white,
                              ),
                            ],
                          ),
                        ),
                      )
                    ],
                  ),
                ),
              ),
            ),
          ),
        ),
        // Container(
        //   decoration: BoxDecoration(
        //     border: Border(
        //       bottom: BorderSide(
        //         width: 15,
        //         color: Color(0xffE8ECEF),
        //       ),
        //     ),
        //   ),
        // ),
      ],
    );
  }

  _buildDateField() {
    final format = DateFormat("dd/MM/yyyy");
    final TextEditingController controller = TextEditingController();
    final now = DateTime.now();

    final nextYear = new DateTime(
      now.year,
      now.month,
      now.day,
    );
    return Column(
      children: [
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
        Container(
          color: Colors.white,
          height: ScreenUtil().setHeight(64),
          width: ScreenUtil().screenWidth,
          alignment: Alignment.center,
          child: SizedBox(
            height: ScreenUtil().setHeight(44),
            width: ScreenUtil().screenWidth - ScreenUtil().setWidth(16),
            child: Container(
              decoration: ShapeDecoration(
                color: Color(0xffE8ECEF),
                shape: RoundedRectangleBorder(
                  side: BorderSide(
                      color: Colors.transparent,
                      width: 1,
                      style: BorderStyle.solid),
                  borderRadius: BorderRadius.circular(7),
                ),
              ),
              //ignore: deprecated_member_use
              child: DateTimeField(
                textAlign: TextAlign.center,
                readOnly: true,
                onChanged: (value) {
                  setState(
                    () {
                      selectedValue = value.toString();
                    },
                  );
                  getPostsByFilter();
                },
                controller: controller,
                format: format,
                onShowPicker: (context, currentValue) {
                  return showDatePicker(
                      context: context,
                      firstDate: lastDate,
                      initialDate: currentValue ?? DateTime.now(),
                      lastDate: nextYear);
                },
                decoration: new InputDecoration(
                  labelText: this.widget.loc.translate(" filter..."),
                  labelStyle: TextStyle(
                    color: Color(0xff98A9BC),
                  ),
                ),
              ),
            ),
          ),
        ),
        Container(
          decoration: BoxDecoration(
            border: Border(
              bottom: BorderSide(
                width: 15,
                color: Color(0xffE8ECEF),
              ),
            ),
          ),
        ),
      ],
    );
    // Container(
    //   decoration: BoxDecoration(
    //     border: Border(
    //       top: BorderSide(
    //         width: ScreenUtil().setWidth(15),
    //         color: Color(0xffE8ECEF),
    //       ),
    //       bottom: BorderSide(
    //         width: ScreenUtil().setWidth(15),
    //         color: Color(0xffE8ECEF),
    //       ),
    //     ),
    //   ),
    //   height: ScreenUtil().setHeight(120),
    //   child: Padding(
    //     padding: EdgeInsets.all(
    //       ScreenUtil().setWidth(15),
    //     ),
    //     child: Container(
    //       decoration: BoxDecoration(
    //         color: Color(0xffE8ECEF),
    //         borderRadius: BorderRadius.circular(7),
    //       ),
    //       margin: EdgeInsets.only(top: ScreenUtil().setHeight(5)),
    //       child: DateTimeField(
    //         textAlign: TextAlign.center,
    //         readOnly: true,
    //         onChanged: (value) {
    //           setState(
    //             () {
    //               selectedValue = value.toString();
    //             },
    //           );
    //           getPostsByFilter();
    //         },
    //         controller: controller,
    //         format: format,
    //         onShowPicker: (context, currentValue) {
    //           return showDatePicker(
    //               context: context,
    //               firstDate: lastDate,
    //               initialDate: currentValue ?? DateTime.now(),
    //               lastDate: nextYear);
    //         },
    //         decoration: new InputDecoration(
    //           labelText: " filter...",
    //           labelStyle: TextStyle(
    //             color: Color(0xff98A9BC),
    //           ),
    //         ),
    //       ),
    //     ),
    //   ),
    // );
  }

  void _loadMoreVertical() {
    setState(() {
      isLoadingVertical = true;
    });
    postsListFilter.addAll(posts.getRange(
        postsListFilter.length, postsListFilter.length + increment));
    new ScrollController(initialScrollOffset: postsListFilter.length * 1000.0);

    // postsListFilter
    // .addAll(List.generate(5, (index) => postsListFilter.length + index));

    setState(() {
      isLoadingVertical = false;
    });
  }
}
