import 'dart:io';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/models/media_source.dart';
import 'package:feed_plugin/pages/source_page.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/video_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:giphy_picker/giphy_picker.dart';
import 'package:hashtagable/hashtagable.dart';
import 'package:cloudinary_public/cloudinary_public.dart';
import 'package:status_alert/status_alert.dart';
import 'package:video_player/video_player.dart';
import 'package:flutter/cupertino.dart';
//multi image picker
import 'dart:async';
import 'package:multi_image_picker/multi_image_picker.dart';
import 'package:image_editor_pro/image_editor_pro.dart';

class AspectRatioVideo extends StatefulWidget {
  AspectRatioVideo(this.controller);

  final VideoPlayerController controller;

  @override
  AspectRatioVideoState createState() => AspectRatioVideoState();
}

class AspectRatioVideoState extends State<AspectRatioVideo> {
  VideoPlayerController get controller => widget.controller;
  bool initialized = false;
  HttpService httpService;
  FeedRepository feedRepository;

  void _onVideoControllerUpdate() {
    if (!mounted) {
      return;
    }
    if (initialized != controller.value.initialized) {
      initialized = controller.value.initialized;
      setState(() {});
    }
  }

  @override
  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    controller.addListener(_onVideoControllerUpdate);
    super.initState();
  }

  @override
  void dispose() {
    controller.removeListener(_onVideoControllerUpdate);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (initialized) {
      return Directionality(
        textDirection: TextDirection.ltr,
        child: Center(
          child: AspectRatio(
            aspectRatio: controller.value?.aspectRatio,
            child: VideoPlayer(controller),
          ),
        ),
      );
    } else {
      return Container();
    }
  }
}

class SharePostPage extends StatefulWidget {
  SharePostPage({
    Key key,
    @required this.currentUser,
    @required this.loc,
  }) : super(key: key);

  final UserModel currentUser;
  final loc;
  @override
  _SharePostPageState createState() => _SharePostPageState();
}

class _SharePostPageState extends State<SharePostPage> {
  FocusNode focusNodeTitle;
  FocusNode focusNodeDescription;

  HttpService httpService;
  FeedRepository feedRepository;
  String url = "https://api.cloudinary.com/v1_1/phonedo/image/upload";
  String pluginTitle;
  GiphyGif _gif;
  final descriptionController = TextEditingController();
  final titleController = TextEditingController();
  final _formKey = GlobalKey<FormState>();
  final cloudinary = CloudinaryPublic('phonedo', 'gfe14pef', cache: false);
  var fileUrl;
  File imageEdit;
  //multi image picker--
  List<Asset> images = [];
  // List<Asset>();
  String jsonUrl = "";
  String myType;

  @override
  void initState() {
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    focusNodeTitle = FocusNode();
    focusNodeDescription = FocusNode();
    super.initState();
  }

  Widget _buildGridView() {
    if (images != null) {
      return GridView.count(
        shrinkWrap: true,
        crossAxisCount: 2,
        children: List.generate(images.length, (index) {
          Asset asset = images[index];
          return Stack(
            children: [
              AssetThumb(
                asset: asset,
                width: 450,
                height: 440,
              ),
              _deleteIcon(images, index)
            ],
          );
        }),
      );
    } else {
      return Container();
    }
  }

  Future<void> loadAssets() async {
    List<Asset> resultList = [];
    // List<Asset>();
    try {
      resultList = await MultiImagePicker.pickImages(
        maxImages: 4,
        enableCamera: true,
        selectedAssets: images,
        cupertinoOptions: CupertinoOptions(takePhotoIcon: "chat"),
        materialOptions: MaterialOptions(
          actionBarColor: "#083356",
          actionBarTitle: this.widget.loc.translate("Example App"),
          allViewTitle: this.widget.loc.translate("All Photos"),
          useDetailsView: false,
          selectCircleStrokeColor: "#000000",
        ),
      );
    } on Exception catch (e) {}

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      images = resultList;
      images.length == 0
          ? myType = null
          : images.length == 4
              ? myType = "0"
              : myType = "Myimg";
    });
  }

  Future<void> getimageditor() async {
    // final geteditimage =
    focusNodeTitle.unfocus();
    focusNodeDescription.unfocus();
    Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) {
          return ImageEditorPro(
            appBarColor: Color(0xFF083356),
            bottomBarColor: Color(0xFF083356),
          );
        },
      ),
    ).then((geteditimage) {
      if (geteditimage != null) {
        setState(() {
          imageEdit = geteditimage;
        });
        myType = "Myimgeditor";
      }
    }).catchError((er) {});
  }
//--multi image picker

//video--
  File fileMedia;
  MediaSource source;

  Future capture(MediaSource source) async {
    focusNodeTitle.unfocus();
    focusNodeDescription.unfocus();
    setState(() {
      this.source = source;
      this.fileMedia = null;
    });

    final result = await Navigator.of(context).push(
      MaterialPageRoute(
        builder: (context) => SourcePage(loc:this.widget.loc),
        settings: RouteSettings(
          arguments: source,
        ),
      ),
    );

    if (result == null) {
      return;
    } else {
      setState(() {
        fileMedia = result;
        myType = "Myvideo";
      });
    }
  }

//--video
  Future<UserModel> getCurrentUserProfile() async {
    int userId = 5;
    UserModel user = await feedRepository.fetchUserData(userId);
    return user;
  }

  Future uploadFile(file, type) async {
    try {
      List<CloudinaryResponse> responseList;
      CloudinaryResponse response;
      var s = "";
      if (type == "Photo") {
        if (images.length > 0) {
          validColor == true ? _onLoading(true) : _onLoading(false);
          responseList = await cloudinary.multiUpload(
            images
                .map(
                  (image) => CloudinaryFile.fromFutureByteData(
                    image.getByteData(),
                    identifier: image.identifier,
                  ),
                )
                .toList(),
          );
          responseList.forEach((e) {
            if (e.url[4] != "s") {
              s = e.url.substring(0, 4).toString() +
                  "s" +
                  e.url.substring(4).toString();
            } else {
              s = e.url;
            }
            this.jsonUrl += s + ",";
          });
          this.jsonUrl = this.jsonUrl.substring(0, this.jsonUrl.length - 1);
        } else {
          validColor == true ? _onLoading(true) : _onLoading(false);
          response = await cloudinary.uploadFile(
            CloudinaryFile.fromFile(file.path,
                resourceType: CloudinaryResourceType.Image),
          );
          if (response.url[4] != "s") {
            s = response.url.substring(0, 4).toString() +
                "s" +
                response.url.substring(4).toString();
          }
        }
      } else if (type == "Video") {
        validColor == true ? _onLoading(true) : _onLoading(false);
        response = await cloudinary.uploadFile(
          CloudinaryFile.fromFile(file.path,
              resourceType: CloudinaryResourceType.Video),
        );
        if (response.url[4] != "s") {
          s = response.url.substring(0, 4).toString() +
              "s" +
              response.url.substring(4).toString();
        }
        // final cloudinaryImgUrl = CloudinaryImage(response.url);
        // final convertImage =
        //     cloudinaryImgUrl.transform().effect('loop').generate();
        // final cloudinaryImgUrl1 = convertImage
        //         .toString()
        //         .substring(0, convertImage.length - 4)
        //         .toString() +
        //     '.gif';
        // str = cloudinaryImgUrl1;
      }
      setState(() {
        fileUrl = response != null ? s : this.jsonUrl;
      });
    } catch (e) {}
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Scaffold(
        resizeToAvoidBottomInset: false,
        appBar: PreferredSize(
          preferredSize: Size.fromHeight(70.0),
          child: AppBar(
            backgroundColor: Color(0xFF083356),
            leading: GestureDetector(
              onTap: () {
                Navigator.pop(context);
              },
              child: Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                child: Icon(Icons.close, size: 27, color: Colors.white),
              ),
            ),
            title: Container(
              alignment: Alignment(-0.3, 0),
              child: Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                child: Text(
                  this.widget.loc.translate("Share post"),
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: Colors.white,
                  ),
                ),
              ),
            ),
          ),
        ),
        body: _getBody(),
      ),
    );
  }

  Widget _getBody() {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Stack(children: <Widget>[
        ListView.separated(
          itemCount: 1,
          itemBuilder: (BuildContext context, int index) {
            return _buildContent(this.widget.currentUser);
          },
          separatorBuilder: (BuildContext context, int index) =>
              const Divider(),
        ),
        Positioned(
          bottom: MediaQuery.of(context).viewInsets.bottom,
          left: 0,
          right: 0,
          child: Container(
            alignment: Alignment.bottomCenter,
            padding: EdgeInsets.all(ScreenUtil().setWidth(16)),
            decoration: BoxDecoration(
              color: Colors.white,
              boxShadow: <BoxShadow>[
                BoxShadow(
                  color: Colors.grey[300],
                  offset: new Offset(5.0, 5.0),
                  blurRadius: 20.0,
                )
              ],
            ),
            child: Row(
              children: [
                Expanded(flex: 2, child: _buildHashtag()),
                Expanded(flex: 5, child: _buildAttachment()),
                Flexible(
                    flex: 1, child: _buildShareButton(this.widget.currentUser))
              ],
            ),
          ),
        ),
      ]),
    );
  }

  Container _buildHashtag() {
    return Container(
      alignment: Alignment.bottomLeft,
      child: TextButton(
        onPressed: () {
          descriptionController.text += ("#");
          descriptionController.selection = TextSelection.fromPosition(
              TextPosition(offset: descriptionController.text.length));
        },
        child: Text(
          this.widget.loc.translate("#Add hashtag"),
          style: TextStyle(color: Colors.black),
        ),
      ),
    );
  }

  _buildAttachment() {
    return Container(
      child: Column(
        children: [
          Container(
            child: Row(
              children: [
                myType == null || myType == "Myvideo"
                    ? Expanded(
                        child: IconButton(
                          icon: const Icon(
                            Icons.videocam_outlined,
                          ),
                          onPressed: () => capture(MediaSource.video),
                        ),
                      )
                    : Expanded(
                        child: IconButton(
                          icon: const Icon(
                            Icons.videocam_outlined,
                            color: Colors.grey,
                          ),
                          onPressed: () => null,
                        ),
                      ),
                myType == "Myimg" || myType == null
                    ? Expanded(
                        child: Container(
                          child: IconButton(
                              icon: Icon(Icons.camera_alt_outlined),
                              onPressed: loadAssets),
                        ),
                      )
                    : Expanded(
                        child: Container(
                          child: IconButton(
                              icon: Icon(
                                Icons.camera_alt_outlined,
                                color: Colors.grey,
                              ),
                              onPressed: null),
                        ),
                      ),
                myType == "Mygif" || myType == null
                    ? Expanded(
                        child: Container(
                          child: IconButton(
                            icon: Icon(
                              Icons.gif,
                            ),
                            onPressed: () async {
                              focusNodeTitle.unfocus();
                              focusNodeDescription.unfocus();

                              GiphyGif res = await GiphyPicker.pickGif(
                                context: context,
                                fullScreenDialog: false,
                                showPreviewPage: true,
                                apiKey: 'EwNGOsJ61NlXaGQ3Nw6ZwxYjZNTyRoW2',
                                decorator: GiphyDecorator(
                                  showAppBar: false,
                                  searchElevation: 4,
                                  giphyTheme: ThemeData.dark(),
                                ),
                              );
                              setState(() {
                                res == null ? myType = null : myType = "Mygif";
                                _gif = res;
                              });
                            },
                          ),
                        ),
                      )
                    : Expanded(
                        child: Container(
                          child: IconButton(
                            icon: Icon(
                              Icons.gif,
                              color: Colors.grey,
                            ),
                            onPressed: null,
                          ),
                        ),
                      ),
                myType == "Myimgeditor" || myType == null
                    ? Expanded(
                        child: Container(
                          child: IconButton(
                              icon: Icon(Icons.important_devices_outlined),
                              onPressed: getimageditor),
                        ),
                      )
                    : Expanded(
                        child: Container(
                          child: IconButton(
                              icon: Icon(
                                Icons.important_devices_outlined,
                                color: Colors.grey,
                              ),
                              onPressed: null),
                        ),
                      ),
              ],
            ),
          ),
        ],
      ),
    );
  }

//הכפתור הירוק בצד
  var validColor = false;
  _buildShareButton(currentUser) {
    // var flatButton =
    return Container(
        // width: ScreenUtil().setHeight(50),
        child: ClipOval(
            child: Material(
                color: validColor == true ? Color(0xFF3DD598) : Colors.grey,
                child: InkWell(
                  splashColor: Color(0xFFFCA64F),
                  child: IconButton(
                    icon: Icon(FontAwesomeIcons.telegramPlane),
                    color: Colors.white,
                    iconSize: 30,
                    onPressed: () async {
                      // if (_formKey.currentState.validate()) {
                      if (images.length > 0) {
                        pluginTitle = "Photo";
                        await uploadFile(images, pluginTitle);
                      } else if (fileMedia != null) {
                        pluginTitle = "Video";
                        await uploadFile(fileMedia, pluginTitle);
                      } else if (_gif != null) {
                        pluginTitle = "Photo";
                        fileUrl = _gif.images.original.url;
                        validColor == true
                            ? _onLoading(true)
                            : _onLoading(false);
                      } else if (imageEdit != null) {
                        pluginTitle = "Photo";
                        await uploadFile(imageEdit, pluginTitle);
                        // fileUrl = imageEdit.images.original.url;
                      }
                      if (titleController.text.isEmpty) {
                        setState(() {
                          validColor = false;
                        });
                        // return;
                      }
                      if (descriptionController.text.isEmpty) {
                        setState(() {
                          validColor = false;
                        });
                        // return;
                      } else {
                        StatusAlert.show(
                          context,
                          duration: Duration(seconds: 2),
                          title: this.widget.loc.translate(
                              'The post will be published in these moments'),
                          configuration: IconConfiguration(
                            icon: Icons.mark_email_read_outlined,
                            size: 70,
                          ),
                        );
                        //Navigator.of(context).pop();
                        validColor = true;
                        feedRepository
                            .addPost(
                              currentUser,
                              titleController.text,
                              descriptionController.text,
                              pluginTitle,
                              fileUrl,
                            )
                            .then((value) => {
                                  StatusAlert.hide(),
                                  value == null
                                      ? StatusAlert.show(
                                          context,
                                          duration: Duration(seconds: 1),
                                          title: this
                                              .widget
                                              .loc
                                              .translate('No post received'),
                                          configuration: IconConfiguration(
                                            icon: Icons
                                                .mark_email_unread_outlined,
                                            size: 70,
                                          ),
                                        )
                                      : {
                                          pluginTitle != null
                                              ? _onLoading(false)
                                              : null,
                                          Navigator.of(context).pop()
                                        },
                                });
                      }
                      // _onLoading(false);
                      // Navigator.of(context).pop();
                      // },
                    },
                  ),
                ))));
  }

//הגודל של המדיה הנבחרת על המסך
  _buildContent(currentUser) {
    return Form(
      key: _formKey,
      // child: Container(
      //   child: Column(
      //  children: [
      // child: Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildProfile(currentUser),
          _buildTitle(),
          _buildDescription(),
          images.length > 0
              ? Container(
                  child: _buildGridView(),
                  height: ScreenUtil().screenHeight / 2,
                )
              : _gif != null
                  ? Container(
                      child: _buildGifContainer(),
                      height: ScreenUtil().setHeight(240),
                    )
                  : imageEdit != null
                      ? Stack(
                          children: [
                            Container(
                                child: Image.file(imageEdit),
                                height: ScreenUtil().setHeight(240)),
                            _deleteIcon(imageEdit, 0)
                          ],
                        )
                      : fileMedia != null
                          ? Container(
                              child: _buildVideoContainer(),
                              height: ScreenUtil().setHeight(240),
                            )
                          : Container(
                              height: ScreenUtil().setHeight(240),
                            ),
        ],
      ),
      // ),
      // ],
      //   ),
      // ),
    );
  }

  _buildProfile(currentUser) {
    return Container(
        child: Padding(
            padding: EdgeInsets.only(
              left: ScreenUtil().setHeight(17),
              top: ScreenUtil().setHeight(20),
              //bottom: MediaQuery.of(context).viewInsets.bottom,
              bottom: ScreenUtil().setHeight(30),
            ),
            child: Row(children: [
              Column(
                children: [
                  Container(
                      margin: EdgeInsets.only(
                        right: ScreenUtil().setWidth(10),
                      ),
                      child: currentUser.profileImg == null || currentUser.profileImg == "" || currentUser.profileImg == "null"
                          ? DefaultProfileImg(
                              firstName: currentUser.firstName,
                              lastName: currentUser.lastName,
                            )
                          // ClipOval(
                          //     child: Material(
                          //       color: Color(0xffE8ECEF),
                          //       child: SizedBox(
                          //         width: ScreenUtil().setWidth(38),
                          //         height: ScreenUtil().setWidth(39),
                          //         child: Center(
                          //           child: Text(
                          //             currentUser.firstName.substring(0, 1) +
                          //                 currentUser.lastName.substring(0, 1),
                          //             style: TextStyle(
                          //               color: Color(0xFF083356),
                          //               fontSize: ScreenUtil().setSp(15),
                          //             ),
                          //           ),
                          //         ),
                          //       ),
                          //     ),
                          //   )
                          : ClipOval(
                              child: Image.network(
                                currentUser.profileImg,
                                width: ScreenUtil().setWidth(38),
                                height: ScreenUtil().setWidth(39),
                                fit: BoxFit.cover,
                              ),
                            )),
                ],
              ),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(163),
                    child: Text(
                      currentUser.lastName != null &&
                              currentUser.lastName != "null"
                          ? currentUser.firstName + " " + currentUser.lastName
                          : currentUser.firstName,
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.w500,
                        color: Colors.black,
                        fontSize: ScreenUtil().setSp(15),
                        fontFamily: 'Rubik',
                      ),
                    ),
                  ),
                  Container(
                    width:
                        ScreenUtil().screenWidth - ScreenUtil().setWidth(165),
                    child: Text(
                      currentUser.about,
                      textAlign: TextAlign.left,
                      maxLines: 1,
                      style: TextStyle(
                        fontWeight: FontWeight.normal,
                        color: Colors.black.withOpacity(0.4),
                        fontSize: ScreenUtil().setSp(13),
                        fontFamily: "Rubik",
                      ),
                    ),
                  ),
                ],
              ),
            ])));
  }

  _buildTitle() {
    return Container(
      padding: EdgeInsets.only(
        // top: ScreenUtil().setHeight(20),
        left: ScreenUtil().setHeight(17),
        // bottom: MediaQuery.of(context).viewInsets.bottom,
        bottom: ScreenUtil().setHeight(17),
      ),
      child: TextFormField(
        focusNode: focusNodeTitle,
        onChanged: (text) {
          if (titleController.text.isEmpty ||
              (descriptionController.text.isEmpty && pluginTitle == null)) {
            setState(() {
              validColor = false;
            });
          } else {
            setState(() {
              validColor = true;
            });
          }
        },
        style: TextStyle(fontSize: 15),
        minLines: 1,
        maxLines: 1,
        decoration: InputDecoration.collapsed(
            hintText: this.widget.loc.translate("Please type title")),
        controller: titleController,
      ),
    );
  }

  _buildDescription() {
    return Container(
      padding: EdgeInsets.only(
        left: ScreenUtil().setHeight(17),
      ),
      child: HashTagTextField(
        focusNode: focusNodeDescription,
        onChanged: (text) {
          if (titleController.text.isEmpty ||
              (descriptionController.text.isEmpty && pluginTitle == null)) {
            setState(() {
              validColor = false;
            });
          } else {
            setState(() {
              validColor = true;
            });
          }
        },
        keyboardType: TextInputType.multiline,
        maxLines: null,
        decoration: InputDecoration.collapsed(
            hintText: this
                .widget
                .loc
                .translate("Please type all you want to talk about...")),
        controller: descriptionController,
        minLines: 6,
        decoratedStyle: TextStyle(
            fontSize: 15, color: Colors.black, fontWeight: FontWeight.bold),
        basicStyle:
            TextStyle(fontSize: ScreenUtil().setSp(15), color: Colors.black),
      ),
      // TextFormField(
      //     style: TextStyle(fontSize: 15),
      //     minLines: 6,
      //     keyboardType: TextInputType.multiline,
      //     maxLines: null,
      //     decoration: InputDecoration.collapsed(
      //         hintText: "Please type all you want to talk about..."),
      //     controller: descriptionController)
    );
  }

  _buildVideoContainer() {
    return Stack(
      children: [
        Container(
          height: ScreenUtil().setHeight(100),
          child: fileMedia == null
              ? Container()
              : (source == MediaSource.video
                  ? VideoWidget(fileMedia)
                  : Container()),
        ),
        _deleteIcon(fileMedia, 0)
      ],
    );
  }

  //  _buildVideoContainer() {
  //   return Container(
  //     height: ScreenUtil().setHeight(100),
  //     child: fileMedia == null
  //         ? Container()
  //         : (source == MediaSource.image
  //             ? Container()
  //             : VideoWidget(fileMedia)),
  //   );
  // }

  _buildGifContainer() {
    return Stack(
      children: [
        Center(child: GiphyImage.original(gif: _gif)),
        _gif != null ? _deleteIcon(_gif, 0) : null
      ],
    );
  }

  _deleteIcon(param, index) {
    return GestureDetector(
      onTap: () {
        setState(() {
          param == fileMedia
              ? {fileMedia = null, myType = null}
              : param == _gif
                  ? {_gif = null, myType = null}
                  : param == imageEdit
                      ? {imageEdit = null, myType = null}
                      : {
                          images.remove(images[index]),
                          images.length < 4 && images.length != 0
                              ? myType = "Myimg"
                              : myType = null
                        };
        });
      },
      child: Padding(
        padding: const EdgeInsets.all(3.0),
        child: CircleAvatar(
          radius: 12.0,
          backgroundColor: Colors.white,
          child: Icon(Icons.close, color: Colors.grey),
        ),
      ),
    );
  }

  var contextShare;
  _onLoading(bool flag) {
    if (flag) {
      showDialog(
          context: context,
          barrierDismissible: false,
          builder: (BuildContext context) {
            contextShare = context;
            return Center(child: CircularProgressIndicator());
          });
    } else {
      Navigator.of(contextShare).pop();
    }
  }
  // _buildAttachment() {
  //   return Container(
  //     child: Column(
  //       children: [
  //         Container(
  //           child: Row(
  //             children: [
  //               this.fileMedia != null
  //                   ? Row(children: [
  //                       IconButton(
  //                         icon: const Icon(
  //                           Icons.videocam_outlined,
  //                           color: Colors.black,
  //                         ),
  //                         onPressed: () => capture(MediaSource.video),
  //                       ),
  //                       Container(
  //                         child: IconButton(
  //                             icon: Icon(Icons.camera_alt_outlined),
  //                             onPressed: null),
  //                       ),
  //                     ])
  //                   : images.length == 0 && this.fileMedia == null
  //                       ? Row(
  //                           children: [
  //                             IconButton(
  //                               icon: const Icon(
  //                                 Icons.videocam_outlined,
  //                                 color: Colors.black,
  //                               ),
  //                               onPressed: () => capture(MediaSource.video),
  //                             ),
  //                             Container(
  //                               child: IconButton(
  //                                   icon: Icon(Icons.camera_alt_outlined),
  //                                   onPressed: loadAssets),
  //                             ),
  //                           ],
  //                         )
  //                       : Row(
  //                           children: [
  //                             IconButton(
  //                               icon: const Icon(
  //                                 Icons.videocam_outlined,
  //                                 color: Colors.grey,
  //                               ),
  //                               onPressed: null,
  //                             ),
  //                             Container(
  //                               child: IconButton(
  //                                   icon: Icon(Icons.camera_alt_outlined),
  //                                   onPressed: loadAssets),
  //                             ),
  //                           ],
  //                         ),
  //               Container(
  //                 child: IconButton(
  //                   icon: Icon(Icons.gif),
  //                   onPressed: () async {
  //                     GiphyGif res = await GiphyPicker.pickGif(
  //                       context: context,
  //                       fullScreenDialog: false,
  //                       showPreviewPage: true,
  //                       apiKey: 'EwNGOsJ61NlXaGQ3Nw6ZwxYjZNTyRoW2',
  //                       decorator: GiphyDecorator(
  //                         showAppBar: false,
  //                         searchElevation: 4,
  //                         giphyTheme: ThemeData.dark(),
  //                       ),
  //                     );
  //                     setState(() {
  //                       _gif = res;
  //                     });
  //                   },
  //                 ),
  //               ),
  //               Container(
  //                 child: IconButton(
  //                     icon: Icon(Icons.important_devices_outlined),
  //                     onPressed: getimageditor),
  //               ),
  //             ],
  //           ),
  //         )
  //       ],
  //     ),
  //   );
  // }

  // Container _buildHashtag() {
  //   return Container(
  //     alignment: Alignment.bottomLeft,
  //     child: TextButton(
  //       onPressed: () {
  //         descriptionController.text += ("#");
  //         descriptionController.selection = TextSelection.fromPosition(
  //             TextPosition(offset: descriptionController.text.length));
  //       },
  //       child: Text("#Add hashtag"),
  //     ),
  //   );
  // }

  // _buildShareButton(currentUser) {
  //   // var flatButton =
  //   return Container(
  //       width: ScreenUtil().setHeight(50),
  //       child: ClipOval(
  //           child: Material(
  //               color: Color(0xFF3DD598),
  //               child: InkWell(
  //                 splashColor: Color(0xFFFCA64F),
  //                 child: IconButton(
  //                   icon: Icon(FontAwesomeIcons.telegramPlane),
  //                   color: Colors.white,
  //                   iconSize: 35,
  //                   onPressed: () async {
  //                     if (_formKey.currentState.validate()) {
  //                       if (images.length > 0) {
  //                         pluginTitle = "Photo";
  //                         await uploadFile(images, pluginTitle);
  //                       } else if (this.fileMedia != null) {
  //                         pluginTitle = "Video";
  //                         await uploadFile(this.fileMedia, pluginTitle);
  //                       } else if (_gif != null) {
  //                         pluginTitle = "Photo";
  //                         fileUrl = _gif.images.original.url;
  //                       } else if (imageEdit != null) {
  //                         pluginTitle = "Photo";
  //                         await uploadFile(imageEdit, pluginTitle);
  //                       }
  //                       feedRepository.addPost(
  //                           currentUser,
  //                           titleController.text,
  //                           descriptionController.text,
  //                           pluginTitle,
  //                           fileUrl);
  //                       Navigator.of(context).pop();
  //                     }
  //                   },
  //                 ),
  //               ))));
  // }

}
