import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/widgets/loadingButtonIndicator.dart';
import 'package:feed_plugin/widgets/post.dart';

class UserPost extends StatefulWidget {
  const UserPost({
    Key key,
    @required this.userData,
    @required this.currentUser,
    @required this.loc,
  }) : super(key: key);

  final UserModel userData;
  final UserModel currentUser;
  final loc;

  @override
  _UserPostState createState() => _UserPostState();
}

class _UserPostState extends State<UserPost> {
  HttpService httpService;
  FeedRepository feedRepository;
  var _scrollController = ScrollController();
  double defaultScreenWidth = 375.0;
  double defaultScreenHeight = 812.0;
  List<PostModel> postsList = [];
  int likeId;
  int dislikeId;
  int saveId;

  final int increment = 10;

  @override
  void initState() {
    _scrollController.addListener(_onScroll);
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);
    super.initState();
  }

  void _onScroll() {
    if (_scrollController.position.pixels ==
        _scrollController.position.maxScrollExtent) {
      getPosts();
    }
  }

  Future<List<PostModel>> getPosts() async {
    await getPostsReports();
    postsList =
        await feedRepository.fetchPostsByUserId(this.widget.userData.id);

    return postsList;
  }

  Future getPostsReports() async {
    List<ReportSubTypeModel> reportsSubTypeList =
        await feedRepository.fetchAllSubType();
    for (var i = 0; i < reportsSubTypeList.length; i++) {
      if (likeId == null || dislikeId == null || saveId == null) {
        if (reportsSubTypeList[i].type == "Like") {
          likeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Dislike") {
          dislikeId = reportsSubTypeList[i].id;
        } else if (reportsSubTypeList[i].type == "Save") {
          saveId = reportsSubTypeList[i].id;
        }
      } else {
        break;
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    var agentName = this.widget.userData.lastName != null &&
            this.widget.userData.lastName != "null"
        ? (this.widget.userData.firstName).toString() +
            " " +
            (this.widget.userData.lastName).toString()
        : (this.widget.userData.firstName).toString();
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
        designSize: Size(defaultScreenWidth, defaultScreenHeight),
        allowFontScaling: false,
        builder: () =>
            //  LayoutBuilder(
            //   builder: (_, BoxConstraints constraints) {
            //     return MaterialApp(
            //       home:
            Scaffold(
          appBar: PreferredSize(
              preferredSize: Size.fromHeight(70.0),
              child: AppBar(
                backgroundColor: Color(0xFF083356),
                leading: GestureDetector(
                    onTap: () {
                      Navigator.of(context).pop();
                    },
                    child: Padding(
                      padding: EdgeInsets.only(top: ScreenUtil().setWidth(9)),
                      child: Icon(Icons.arrow_back, color: Colors.white),
                    )),
                title: Padding(
                  padding: EdgeInsets.only(
                      left: ScreenUtil().setWidth(10),
                      top: ScreenUtil().setWidth(9)),
                  child: Text(
                    agentName.toString() + " post",
                    style: TextStyle(color: Colors.white),
                  ),
                ),
              )),
          body: Directionality(
            textDirection: TextDirection.ltr,
            child: FutureBuilder(
              future: getPosts(),
              builder: (context, projectSnap) {
                if (projectSnap.connectionState == ConnectionState.waiting ||
                    projectSnap.connectionState == ConnectionState.none) {
                  return Center(child: LoadingIndicatorDark());
                }
                return Stack(children: [
                  RefreshIndicator(
                      onRefresh: () {
                        return getPosts();
                      },
                      child:
                          // LazyLoadScrollView(
                          //   onEndOfPage: () => null,
                          //   child: ListView(
                          //     children: [
                          //       ListView.separated(
                          //         shrinkWrap: true,
                          //         physics: NeverScrollableScrollPhysics(),
                          //         reverse: true,
                          //         // cacheExtent: 9999,
                          //         controller: _scrollController,
                          //         itemCount: postsList.length,
                          //         itemBuilder: (BuildContext context, int index) {
                          //           PostModel post = postsList[index];
                          //           List<String> images =
                          //               postsList[index].attachedUrl.split(",");
                          //           return Container(
                          //             decoration: BoxDecoration(
                          //               border: Border(
                          //                 bottom: BorderSide(
                          //                   width: 15,
                          //                   color: Color(0xffE8ECEF),
                          //                 ),
                          //               ),
                          //             ),
                          //             child: FeedPost(
                          //               postData: post,
                          //               currentUser: this.widget.currentUser,
                          //               images: images,
                          //               likeId: likeId,
                          //               dislikeId: dislikeId,
                          //               saveId: saveId,
                          //               commentsLength: 0,
                          //             ),
                          //           );
                          //         },
                          //         separatorBuilder:
                          //             (BuildContext context, int index) =>
                          //                 const Divider(),
                          //       ),
                          //     ],
                          //   ),
                          // ),
                          ListView.builder(
                        physics: const AlwaysScrollableScrollPhysics(),
                        // reverse: true,
                        // cacheExtent: 9999,
                        controller: _scrollController,
                        itemCount: postsList.length,
                        itemBuilder: (BuildContext context, int index) {
                          PostModel post = postsList[index];
                          List<String> images =
                              postsList[index].attachedUrl.split(",");
                          // FeedPost feed = list[index];
                          return Container(
                            decoration: BoxDecoration(
                              border: Border(
                                bottom: BorderSide(
                                  width: 15,
                                  color: Color(0xffE8ECEF),
                                ),
                              ),
                            ),
                            child: FeedPost(
                              key: Key("F" + post.id.toString()),
                              postData: post,
                              currentUser: this.widget.currentUser,
                              images: images,
                              likeId: likeId,
                              dislikeId: dislikeId,
                              saveId: saveId,
                              commentsLength: 0,
                              loc: this.widget.loc,
                            ),

                            // feed,
                          );
                        },
                        // separatorBuilder:
                        //     (BuildContext context, int index) =>
                        //         const Divider(),
                      )),
                ]);
              },
            ),
          ),
        ),
        //     );
        //   },
        // ),
      ),
    );
  }
}
