// import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';
import 'dart:ui';

import 'package:feed_plugin/pages/comments/screens/chat.dart';
import 'package:feed_plugin/pages/likes_and_dislikes.dart';
import 'package:feed_plugin/repo/feed_repository.dart';
import 'package:feed_plugin/service/http_service.dart';
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:feed_plugin/widgets/parsed_text.dart';
import 'package:flutter/foundation.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/user_posts.dart';
import 'package:feed_plugin/widgets/basics/network_player_widget.dart';
import 'package:feed_plugin/widgets/popup.dart';

import 'package:timeago/timeago.dart' as timeago;
import 'package:flutter/material.dart';
import 'package:pk_skeleton/pk_skeleton.dart';

import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:number_display/number_display.dart';
import 'package:status_alert/status_alert.dart';

// import 'package:video_viewer/video_viewer.dart';

import 'package:esys_flutter_share/esys_flutter_share.dart';
import 'package:story_view/story_view.dart';

final display = createDisplay(
  length: 4,
  separator: ',',
  decimal: 2,
);

class FeedPost extends StatefulWidget {
  const FeedPost({
    Key key,
    @required this.postData,
    @required this.currentUser,
    @required this.likeId,
    @required this.dislikeId,
    @required this.saveId,
    @required this.images,
    @required this.commentsLength,
    @required this.loc,
  }) : super(key: key);

  final PostModel postData;
  final UserModel currentUser;
  final int likeId;
  final int dislikeId;
  final int saveId;
  final List<String> images;
  final int commentsLength;
  final loc;
  @override
  _FeedPostState createState() => _FeedPostState();
}

class _FeedPostState extends State<FeedPost> {
  HttpService httpService;
  FeedRepository feedRepository;

  List<ReportModel> likesList;
  List<ReportModel> dislikesList;

  bool mySave;
  bool myLike;
  bool myDislike;
  bool flagReport = true;

  int commentsOnPost;
  // int saveReportId = 0;
  // int likeReportId = 0;
  // int disLikeReportId = 0;
  int reportLikeId = 0;
  int reportDislikeId = 0;
  int reportSaveId = 0;

  UserModel userData;

  String firstHalf;
  String secondHalf;
  bool flag = true;

  var contextShare;

  List<StoryItem> storyItems = [];
  final controller = StoryController();

  // ReportModel newReport;
  // Map<String, Map<String, VideoSource>> database;
  // VideoViewerController controller;

  @override
  void initState() {
    likesList = [];
    dislikesList = [];

    mySave = false;
    myLike = false;
    myDislike = false;

    commentsOnPost = 0;
    userData = this.widget.postData.user;

    httpService = HttpService("gogog");
    feedRepository = FeedRepository(httpService);

    if (widget.postData.description.length > 241) {
      firstHalf = widget.postData.description.substring(0, 241);
      secondHalf = widget.postData.description
          .substring(241, widget.postData.description.length);
    } else {
      firstHalf = widget.postData.description;
      secondHalf = "";
    }

    if (this.widget.images != null) {
      this.widget.images.forEach((img) {
        storyItems.add(StoryItem.pageImage(
            url: img, controller: controller, imageFit: BoxFit.contain));
      });
    }

    getLikesListByPostId(this.widget.postData.id).then(
      (data) async {
        await getPostComments();
      },
    );
    super.initState();
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }

  Future<void> getLikesListByPostId(postId) async {
    List<ReportModel> reportsLikeList = [];
    List<ReportModel> reportsDislikeList = [];
    List<ReportModel> reportsSaveList = [];

    bool isDislike = false;
    bool isLike = false;
    bool isSave = false;

    await feedRepository.fetchPostReports(postId).then((reportsList) => {
          reportsList.forEach((e) {
            if (e.type.id == this.widget.likeId) {
              reportsLikeList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isLike = true;
                reportLikeId = e.id;
              }
            } else if (e.type.id == this.widget.dislikeId) {
              reportsDislikeList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isDislike = true;
                reportDislikeId = e.id;
              }
            } else if (e.type.id == this.widget.saveId) {
              reportsSaveList.add(e);
              if (e.user.id == this.widget.currentUser.id) {
                isSave = true;
                reportSaveId = e.id;
              }
            } else {
              if (e.user.id == this.widget.currentUser.id) {
                if (mounted) {
                  this.setState(() {
                    flagReport = false;
                  });
                }
              }
            }
          }),
          if (mounted)
            {
              this.setState(() {
                likesList = reportsLikeList;
                dislikesList = reportsDislikeList;
                myLike = isLike;
                myDislike = isDislike;
                mySave = isSave;
              })
            }
        });
  }

  getPostComments() async {
    await feedRepository
        .fetchPostComments(this.widget.postData.id)
        .then((comments) => {
              if (mounted)
                {
                  setState(() {
                    commentsOnPost = comments.length;
                  })
                }
            });
  }

  Future<void> removeReportPost(reportId, subTypeId) async {
    List<ReportModel> dislikes = [];
    List<ReportModel> likes = [];
    await feedRepository.removeReport(reportId).then((value) => {
          if (subTypeId == this.widget.likeId)
            {
              likesList.forEach((like) {
                if (like.id != reportId) {
                  likes.add(like);
                }
              }),
              setState(() {
                likesList = likes;
              }),
            }
          else if (subTypeId == this.widget.dislikeId)
            {
              dislikesList.forEach((dislike) {
                if (dislike.id != reportId) {
                  dislikes.add(dislike);
                }
              }),
              setState(() {
                dislikesList = dislikes;
              }),
            }
        });
  }

  Future<void> reportPost(subTypeId) async {
    await feedRepository
        .addReport(
            subTypeId, this.widget.currentUser.id, this.widget.postData.id)
        .then((data) => {
              if (subTypeId == this.widget.likeId)
                {
                  setState(() {
                    reportLikeId = data.id;
                    likesList.add(data);
                  }),
                }
              else
                {
                  if (subTypeId == this.widget.dislikeId)
                    {
                      setState(() {
                        reportDislikeId = data.id;
                        dislikesList.add(data);
                      }),
                    }
                  else
                    {
                      if (subTypeId == this.widget.saveId)
                        {
                          reportSaveId = data.id,
                        }
                    }
                }
            });
  }

  Future<void> show() async {
    StatusAlert.show(
      context,
      duration: Duration(seconds: 2),
      title: this.widget.loc.translate('Save post'),
      subtitle: this.widget.loc.translate('this post saved for later'),
      configuration: IconConfiguration(
        icon: Icons.favorite_border_rounded,
        size: 80,
      ),
    );
    await reportPost(this.widget.saveId);
  }

  _onLoading(bool flag) {
    if (flag) {
      showDialog(
          context: context,
          barrierDismissible: false,
          builder: (BuildContext context) {
            contextShare = context;
            return Center(child: CircularProgressIndicator());
          });
    } else {
      Navigator.of(contextShare).pop();
    }
  }

  removeUserPost() {
    showDialog(
        context: context,
        barrierDismissible: false,
        builder: (BuildContext context1) {
          return AlertDialog(
            content: Text(this
                .widget
                .loc
                .translate("Are you sure you want to delete this post?")),
            actions: [
              TextButton(
                onPressed: () {
                  Navigator.of(context).pop();
                },
                child: Text(this.widget.loc.translate("Cancel")),
              ),
              TextButton(
                onPressed: () {
                  feedRepository
                      .removePost(this.widget.postData.id)
                      .then((value) => {
                            Navigator.of(context).pop(),
                          });
                },
                child: Text(this.widget.loc.translate("Ok")),
              ),
            ],
          );
        }).then((value) => {Navigator.of(context).pop()});
  }

  @override
  Widget build(BuildContext context) {
    Widget buildNetwork(url) => NetworkPlayerWidget(url: url);

    Future<void> share(title, description, attachedUrl, user) async {
      _onLoading(true);
      if (this.widget.postData.type == "Photo") {
        List<Uint8List> bytes = [];
        Map<String, List<int>> newMap = new Map<String, List<int>>();
        var files;

        for (var i = 0; i < this.widget.images.length; i++) {
          var request =
              await HttpClient().getUrl(Uri.parse(this.widget.images[i]));
          var response = await request.close();
          bytes.add(await consolidateHttpClientResponseBytes(response));
        }

        files = bytes.asMap();
        files.forEach((key, value) {
          var arr = widget.images[key].split(".").toList();
          var type = arr[arr.length - 1];
          type.contains("gif") ? type = "gif" : type = "jpg";
          newMap.putIfAbsent(
              key.toString() + '.' + type.toString(), () => value);
        });

        _onLoading(false);

        await Share.files(title, newMap, '*/*',
            text: title + "\n" + "\n" + description);
      } else if (this.widget.postData.type == "Video") {
        var request = await HttpClient().getUrl(Uri.parse(attachedUrl));
        var response = await request.close();
        Uint8List bytes = await consolidateHttpClientResponseBytes(response);
        var files = {'video.mp4': bytes};

        _onLoading(false);

        await Share.files(title, files, '*/*',
            text: title + "\n" + "\n" + description);
      } else {
        _onLoading(false);

        Share.text(title, title + "\n" + "\n" + description, 'text/plain');
      }
    }

    final date2 = DateTime.now();
    final difference =
        date2.difference(this.widget.postData.createdAt).inMinutes;
    final fifteenAgo =
        new DateTime.now().subtract(new Duration(minutes: difference));
    return likesList == []
        ? Directionality(
            textDirection: TextDirection.ltr,
            child: PKCardSkeleton(
              isCircularImage: true,
              isBottomLinesActive: true,
            ),
          )
        : Directionality(
            textDirection: TextDirection.ltr,
            child: Container(
              color: Colors.white,
              child: userData == null
                  ? PKCardSkeleton(
                      isCircularImage: true,
                      isBottomLinesActive: true,
                    )
                  : Container(
                      padding: EdgeInsets.symmetric(
                          horizontal: ScreenUtil().setWidth(1.0)),
                      child: Container(
                        margin: EdgeInsets.only(
                            top: ScreenUtil().setWidth(23.0),
                            bottom: ScreenUtil().setWidth(8)),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.center,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Row(
                              children: [
                                Column(
                                  children: [
                                    Container(
                                        margin: EdgeInsets.only(
                                            left: ScreenUtil().setWidth(12.0)),
                                        child: GestureDetector(
                                          onTap: () {
                                            Navigator.push(
                                              context,
                                              MaterialPageRoute(
                                                builder: (context) => UserPost(
                                                  userData: userData,
                                                  currentUser:
                                                      this.widget.currentUser,
                                                  loc: this.widget.loc,
                                                ),
                                              ),
                                              // ),
                                            );
                                          },
                                          child: userData.profileImg == null ||
                                                  userData.profileImg == "" ||
                                                  userData.profileImg == "null"
                                              ? DefaultProfileImg(
                                                  firstName: userData.firstName,
                                                  lastName: userData.lastName,
                                                )

                                              // ClipOval(
                                              //     child: Material(
                                              //       color: Color(0xffE8ECEF),
                                              //       child: SizedBox(
                                              //         width: ScreenUtil()
                                              //             .setWidth(38),
                                              //         height: ScreenUtil()
                                              //             .setWidth(39),
                                              //         child: Center(
                                              //           child: Text(
                                              //             userData.firstName
                                              //                     .substring(
                                              //                         0, 1) +
                                              //                 userData.lastName
                                              //                     .substring(
                                              //                         0, 1),
                                              //             style: TextStyle(
                                              //               color:
                                              //                   Color(0xFF083356),
                                              //               fontSize: ScreenUtil()
                                              //                   .setSp(15),
                                              //           ),
                                              //         ),
                                              //       ),
                                              //     ),
                                              //   ),
                                              // )
                                              : ClipOval(
                                                  child: Image.network(
                                                    userData.profileImg,
                                                    width: ScreenUtil()
                                                        .setWidth(38),
                                                    height: ScreenUtil()
                                                        .setWidth(39),
                                                    fit: BoxFit.cover,
                                                  ),
                                                ),
                                        )),
                                  ],
                                ),
                                Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Container(
                                        width: ScreenUtil().setWidth(250),
                                        margin: EdgeInsets.only(
                                            left: ScreenUtil().setWidth(10.0)),
                                        child: Text(
                                          userData.lastName != "null"
                                              ? userData.firstName +
                                                  " " +
                                                  userData.lastName
                                              : userData.firstName,
                                          textAlign: TextAlign.left,
                                          maxLines: 1,
                                          style: TextStyle(
                                            fontWeight: FontWeight.w500,
                                            color: Colors.black,
                                            fontSize: ScreenUtil().setSp(15),
                                            fontFamily: 'Rubik',
                                          ),
                                        )),
                                    Container(
                                      width: ScreenUtil().setWidth(250),
                                      margin: EdgeInsets.only(
                                          left: ScreenUtil().setWidth(10.0)),
                                      child: Text(
                                        userData.about,
                                        textAlign: TextAlign.left,
                                        maxLines: 1,
                                        style: TextStyle(
                                          fontWeight: FontWeight.normal,
                                          color: Color(0xff98A9BC),
                                          fontSize: ScreenUtil().setSp(13),
                                          fontFamily: "Rubik",
                                        ),
                                      ),
                                    ),
                                    Container(
                                      margin: EdgeInsets.only(
                                          left: ScreenUtil().setWidth(10.0)),
                                      child: Text(
                                        timeago.format(fifteenAgo,
                                            locale: 'en_short'),
                                        style:
                                            TextStyle(color: Color(0xff98A9BC)),
                                      ),
                                    )
                                  ],
                                ),
                                Column(
                                  children: [
                                    Container(
                                        margin: EdgeInsets.only(
                                            left: ScreenUtil().setWidth(3)),
                                        child: IconButton(
                                          icon: Icon(Icons.more_vert),
                                          iconSize: 35,
                                          onPressed: () {
                                            showModalBottomSheet(
                                              context: context,
                                              builder: (context) {
                                                return Directionality(
                                                  textDirection:
                                                      TextDirection.ltr,
                                                  child: Wrap(
                                                    children: [
                                                      ListTile(
                                                        leading: Icon(
                                                          Icons
                                                              .bookmarks_outlined,
                                                          color: Colors.black,
                                                        ),
                                                        title: mySave
                                                            ? Text(this
                                                                .widget
                                                                .loc
                                                                .translate(
                                                                    'Cancel saving this item for later'))
                                                            : Text(this
                                                                .widget
                                                                .loc
                                                                .translate(
                                                                    'Save this item for later')),
                                                        onTap: () {
                                                          setState(() {
                                                            mySave = !mySave;
                                                          });
                                                          if (mySave) {
                                                            Navigator.of(
                                                                    context)
                                                                .pop();
                                                            show();
                                                          } else {
                                                            Navigator.of(
                                                                    context)
                                                                .pop();
                                                            removeReportPost(
                                                                reportSaveId,
                                                                this
                                                                    .widget
                                                                    .saveId);
                                                          }
                                                        },
                                                      ),
                                                      ListTile(
                                                        leading: Icon(
                                                          Icons.share_outlined,
                                                          color: Colors.black,
                                                        ),
                                                        title: Text(this
                                                            .widget
                                                            .loc
                                                            .translate(
                                                                'Share via')),
                                                        onTap: () {
                                                          var post = this
                                                              .widget
                                                              .postData;
                                                          Navigator.of(context)
                                                              .pop();
                                                          share(
                                                              post.title,
                                                              post.description,
                                                              post.attachedUrl,
                                                              userData);
                                                        },
                                                      ),
                                                      ListTile(
                                                        leading: Icon(
                                                          Icons.cancel,
                                                          color: Colors.black,
                                                        ),
                                                        title: Text(this
                                                            .widget
                                                            .loc
                                                            .translate(
                                                                'Unfollow Janet Doe')),
                                                      ),
                                                      ListTile(
                                                        onTap: flagReport ==
                                                                    true ||
                                                                flagReport ==
                                                                    null
                                                            ? () {
                                                                showDialog(
                                                                  context:
                                                                      context,
                                                                  builder:
                                                                      (BuildContext
                                                                          context) {
                                                                    return Reports(
                                                                      loc: this
                                                                          .widget
                                                                          .loc,
                                                                      currentUser: this
                                                                          .widget
                                                                          .currentUser,
                                                                      postData: this
                                                                          .widget
                                                                          .postData,
                                                                    );
                                                                  },
                                                                ).then(
                                                                    (value) => {
                                                                          setState(
                                                                              () {
                                                                            flagReport =
                                                                                value;
                                                                          }),
                                                                          Navigator.of(context)
                                                                              .pop()
                                                                        });
                                                              }
                                                            : null,
                                                        leading: flagReport ==
                                                                    true ||
                                                                flagReport ==
                                                                    null
                                                            ? Icon(
                                                                Icons
                                                                    .outlined_flag_rounded,
                                                                color: Colors
                                                                    .black,
                                                              )
                                                            : Icon(
                                                                Icons
                                                                    .outlined_flag_rounded,
                                                                color:
                                                                    Colors.grey,
                                                              ),
                                                        title: flagReport ==
                                                                    true ||
                                                                flagReport ==
                                                                    null
                                                            ? Text(this
                                                                .widget
                                                                .loc
                                                                .translate(
                                                                    'Report the post'))
                                                            : Text(
                                                                this
                                                                    .widget
                                                                    .loc
                                                                    .translate(
                                                                        'Report the post'),
                                                                style: TextStyle(
                                                                    color: Colors
                                                                        .grey),
                                                              ),
                                                      ),
                                                      widget.postData.user.id ==
                                                              widget.currentUser
                                                                  .id
                                                          ? ListTile(
                                                              leading: Icon(
                                                                Icons
                                                                    .delete_outline,
                                                                color: Colors
                                                                    .black,
                                                              ),
                                                              title: Text(this
                                                                  .widget
                                                                  .loc
                                                                  .translate(
                                                                      'Delete post')),
                                                              onTap: () async {
                                                                await removeUserPost();
                                                              },
                                                            )
                                                          : Container(),
                                                    ],
                                                  ),
                                                );
                                              },
                                            );
                                          },
                                        ))
                                  ],
                                )
                              ],
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  top: ScreenUtil().setWidth(10),
                                  left: ScreenUtil().setWidth(12.0)),
                              width: ScreenUtil().screenWidth,
                              child: Parse(
                                myText: this.widget.postData.title,
                                style: TextStyle(
                                    fontSize: ScreenUtil().setSp(15),
                                    fontFamily: 'Rubik',
                                    color: Colors.black),
                              ),
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  left: ScreenUtil().setWidth(12.0)),
                              width: ScreenUtil().screenWidth,
                              child: secondHalf.isEmpty
                                  ? Parse(
                                      myText: firstHalf,
                                      style: TextStyle(
                                          fontSize: ScreenUtil().setSp(15),
                                          fontFamily: 'Rubik',
                                          color: Colors.black),
                                    )
                                  : new Column(
                                      children: <Widget>[
                                        Parse(
                                          myText: flag
                                              ? (firstHalf + "...")
                                              : (firstHalf + secondHalf),
                                          style: TextStyle(
                                              fontSize: ScreenUtil().setSp(15),
                                              fontFamily: 'Rubik',
                                              color: Colors.black),
                                        ),
                                        new InkWell(
                                          child: new Row(
                                            mainAxisAlignment:
                                                MainAxisAlignment.end,
                                            children: <Widget>[
                                              Padding(
                                                padding: const EdgeInsets.only(
                                                    right: 7),
                                                child: new Text(
                                                  flag
                                                      ? this
                                                          .widget
                                                          .loc
                                                          .translate("see more")
                                                      : this
                                                          .widget
                                                          .loc
                                                          .translate(
                                                              "see less"),
                                                  style: new TextStyle(
                                                      color: Colors.blue),
                                                ),
                                              ),
                                            ],
                                          ),
                                          onTap: () {
                                            setState(() {
                                              flag = !flag;
                                            });
                                          },
                                        ),
                                      ],
                                    ),
                            ),
                            Container(
                                margin: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(5)),
                                child: this.widget.postData.type == "Photo"
                                    ? Container(
                                        height: ScreenUtil().setHeight(250),
                                        width: ScreenUtil().screenWidth,
                                        child: this.widget.images.length > 1
                                            ? StoryView(
                                                storyItems: storyItems,
                                                controller: controller,
                                                repeat: true,
                                                // progressPosition:
                                                //     ProgressPosition.bottom,
                                              )
                                            : Image.network(
                                                this
                                                    .widget
                                                    .postData
                                                    .attachedUrl,
                                                fit: BoxFit.contain,
                                              ))
                                    : this.widget.postData.type == "Video"
                                        ? Container(
                                            height: ScreenUtil().setHeight(155),
                                            width: ScreenUtil().screenWidth,
                                            child: buildNetwork(
                                              this.widget.postData.attachedUrl,
                                            ))
                                        : Container()),
                            Column(
                              children: [
                                Divider(
                                  color: Color(0xff98A9BC),
                                ),
                              ],
                            ),
                            Container(
                              margin: EdgeInsets.only(
                                  left: ScreenUtil().setWidth(12.0)),
                              child: Row(
                                children: [
                                  Container(
                                    width: ScreenUtil().setWidth(175),
                                    margin: EdgeInsets.only(
                                      top: ScreenUtil().setWidth(8),
                                      bottom: ScreenUtil().setWidth(8),
                                    ),
                                    child: GestureDetector(
                                      onTap: () async {
                                        var result = await Navigator.push(
                                          context,
                                          new MaterialPageRoute(
                                            builder: (BuildContext context) =>
                                                new ChatScreen(
                                              currentUser:
                                                  this.widget.currentUser,
                                              senderName: this
                                                      .widget
                                                      .currentUser
                                                      .firstName +
                                                  " " +
                                                  this
                                                      .widget
                                                      .currentUser
                                                      .lastName,
                                              about:
                                                  this.widget.currentUser.about,
                                              senderImage: this
                                                  .widget
                                                  .currentUser
                                                  .profileImg,
                                              post: FeedPost(
                                                postData: this.widget.postData,
                                                currentUser:
                                                    this.widget.currentUser,
                                                likeId: this.widget.likeId,
                                                saveId: this.widget.saveId,
                                                dislikeId:
                                                    this.widget.dislikeId,
                                                images: this.widget.images,
                                                commentsLength:
                                                    this.widget.commentsLength,
                                                loc: this.widget.loc,
                                              ),
                                              loc: this.widget.loc,
                                            ),
                                          ),
                                        );
                                        if (mounted) {
                                          setState(() {
                                            if (result.commentsLength > 0) {
                                              commentsOnPost =
                                                  result.commentsLength;
                                            } else if (result.commentsLength ==
                                                -1) {
                                              commentsOnPost = 0;
                                            }
                                            getLikesListByPostId(
                                                result.postData.id);
                                          });
                                        }
                                      },
                                      child: this.widget.commentsLength > 0
                                          ? Text(
                                              this
                                                      .widget
                                                      .loc
                                                      .translate("Show all ") +
                                                  display(this
                                                      .widget
                                                      .commentsLength) +
                                                  this
                                                      .widget
                                                      .loc
                                                      .translate(" comments"),
                                              style: TextStyle(
                                                  fontSize:
                                                      ScreenUtil().setSp(13),
                                                  color: Color(0xff98A9BC)),
                                            )
                                          : this.widget.commentsLength == -1
                                              ? Text("")
                                              : this.commentsOnPost > 0
                                                  ? Text(
                                                      this.widget.loc.translate(
                                                              "Show all ") +
                                                          display(
                                                              commentsOnPost) +
                                                          this
                                                              .widget
                                                              .loc
                                                              .translate(
                                                                  " comments"),
                                                      style: TextStyle(
                                                          fontSize: ScreenUtil()
                                                              .setSp(13),
                                                          color: Color(
                                                              0xff98A9BC)),
                                                    )
                                                  : Text(""),
                                    ),
                                  ),
                                  Container(
                                    alignment: Alignment.centerRight,
                                    width: ScreenUtil().setWidth(180),
                                    child: GestureDetector(
                                      onTap: () {
                                        Navigator.push(
                                          context,
                                          MaterialPageRoute(
                                            builder: (context) =>
                                                LikesAndDislikes(
                                                    loc: this.widget.loc,
                                                    likesList: likesList,
                                                    dislikesList: dislikesList,
                                                    postTitle: this
                                                        .widget
                                                        .postData
                                                        .title),
                                          ),
                                        );
                                      },
                                      child: likesList.length +
                                                  dislikesList.length >
                                              0
                                          ? Text(
                                              this
                                                      .widget
                                                      .loc
                                                      .translate("Show ") +
                                                  display(likesList.length +
                                                      dislikesList.length) +
                                                  this.widget.loc.translate(
                                                      " Likes&Dislikes"),
                                              style: TextStyle(
                                                  fontSize:
                                                      ScreenUtil().setSp(13),
                                                  color: Color(0xff98A9BC)),
                                            )
                                          : Text(""),
                                    ),
                                  ),
                                ],
                              ),
                            ),
                            Column(
                              children: [
                                Divider(
                                  color: Color(0xff98A9BC),
                                ),
                              ],
                            ),
                            Container(
                              child: Row(
                                children: [
                                  Expanded(
                                      child: Column(children: [
                                    IconButton(
                                      icon: myLike
                                          ? Icon(Icons.thumb_up,
                                              color: Colors.green)
                                          : Icon(Icons.thumb_up_off_alt,
                                              color: Colors.black),
                                      onPressed: myDislike
                                          ? null
                                          : () {
                                              setState(
                                                () {
                                                  myLike = !myLike;
                                                  if (myLike) {
                                                    reportPost(
                                                        this.widget.likeId);
                                                    if (myDislike) {
                                                      myDislike = false;
                                                      removeReportPost(
                                                          reportDislikeId,
                                                          this
                                                              .widget
                                                              .dislikeId);
                                                    }
                                                  } else {
                                                    removeReportPost(
                                                        reportLikeId,
                                                        this.widget.likeId);
                                                  }
                                                },
                                              );
                                            },
                                    ),
                                    Text(
                                      this.widget.loc.translate("Like"),
                                      style: TextStyle(
                                          fontSize: ScreenUtil().setSp(12)),
                                    )
                                  ])),
                                  Expanded(
                                    child: Column(children: [
                                      IconButton(
                                        icon: myDislike
                                            ? Icon(Icons.thumb_down,
                                                color: Colors.red)
                                            : Icon(
                                                Icons.thumb_down_off_alt,
                                                color: Colors.black,
                                              ),
                                        onPressed: myLike
                                            ? null
                                            : () {
                                                setState(
                                                  () {
                                                    myDislike = !myDislike;
                                                    if (myDislike) {
                                                      reportPost(this
                                                          .widget
                                                          .dislikeId);
                                                      if (myLike) {
                                                        myLike = false;
                                                        removeReportPost(
                                                            reportLikeId,
                                                            this.widget.likeId);
                                                      }
                                                    } else {
                                                      removeReportPost(
                                                          reportDislikeId,
                                                          this
                                                              .widget
                                                              .dislikeId);
                                                    }
                                                  },
                                                );
                                              },
                                      ),
                                      Text(
                                        this.widget.loc.translate("Dislike"),
                                        style: TextStyle(
                                            fontSize: ScreenUtil().setSp(12)),
                                      )
                                    ]),
                                  ),
                                  Expanded(
                                    child: Column(
                                      children: [
                                        IconButton(
                                            icon: Icon(
                                              Icons.messenger_outline,
                                              color: Colors.black,
                                            ),
                                            onPressed: () async {
                                              var result = await Navigator.push(
                                                  context,
                                                  new MaterialPageRoute(
                                                    builder: (BuildContext
                                                            context) =>
                                                        new ChatScreen(
                                                      currentUser: this
                                                          .widget
                                                          .currentUser,
                                                      senderName: this
                                                              .widget
                                                              .currentUser
                                                              .firstName +
                                                          " " +
                                                          this
                                                              .widget
                                                              .currentUser
                                                              .lastName,
                                                      about: this
                                                          .widget
                                                          .currentUser
                                                          .about,
                                                      senderImage: this
                                                          .widget
                                                          .currentUser
                                                          .profileImg,
                                                      post: FeedPost(
                                                        postData: this
                                                            .widget
                                                            .postData,
                                                        currentUser: this
                                                            .widget
                                                            .currentUser,
                                                        likeId:
                                                            this.widget.likeId,
                                                        saveId:
                                                            this.widget.saveId,
                                                        dislikeId: this
                                                            .widget
                                                            .dislikeId,
                                                        images:
                                                            this.widget.images,
                                                        commentsLength: this
                                                            .widget
                                                            .commentsLength,
                                                        loc: this.widget.loc,
                                                      ),
                                                      loc: this.widget.loc,
                                                    ),
                                                  ));

                                              setState(() {
                                                if (result.commentsLength > 0) {
                                                  commentsOnPost =
                                                      result.commentsLength;
                                                } else if (result
                                                        .commentsLength ==
                                                    -1) {
                                                  commentsOnPost = 0;
                                                }
                                                getLikesListByPostId(
                                                    result.postData.id);
                                              });
                                            }),
                                        Text(
                                          this.widget.loc.translate("Comments"),
                                          style: TextStyle(
                                            fontSize: ScreenUtil().setSp(12),
                                          ),
                                        )
                                      ],
                                    ),
                                  ),
                                  Expanded(
                                      child: Column(children: [
                                    TextButton(
                                      child: Icon(
                                        Icons.share_outlined,
                                        color: Colors.black,
                                      ),
                                      onPressed: () {
                                        share(
                                            this.widget.postData.title,
                                            this.widget.postData.description,
                                            this.widget.postData.attachedUrl,
                                            userData);
                                      },
                                    ),
                                    Text(
                                      this.widget.loc.translate("Share"),
                                      style: TextStyle(
                                          fontSize: ScreenUtil().setSp(12)),
                                    )
                                  ])),
                                  Expanded(
                                      child: Column(children: [
                                    IconButton(
                                        icon: Icon(
                                          mySave
                                              ? Icons.favorite
                                              : Icons.favorite_outline,
                                          color: mySave
                                              ? Colors.pink
                                              : Colors.black,
                                        ),
                                        onPressed: () {
                                          setState(() {
                                            mySave = !mySave;
                                          });
                                          mySave
                                              ? show()
                                              : removeReportPost(reportSaveId,
                                                  this.widget.saveId);
                                        }),
                                    Text(
                                      this.widget.loc.translate("Save"),
                                      style: TextStyle(
                                          fontSize: ScreenUtil().setSp(12)),
                                    )
                                  ])),
                                ],
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
            ),
          );
  }
}
